@@ -58,7 +58,13 @@ sub xdg_open {
 
 sub xdg_open_mail {
 	my ( $self, $dialog, $mail, $user_data ) = @_;
-	system("xdg-open mailto:$mail");
+	system("xdg-email $mail $user_data");
+	return TRUE;
+}
+
+sub nautilus_sendto {
+	my ( $self, $user_data ) = @_;
+	system("nautilus-sendto $user_data &");
 	return TRUE;
 }
 
@@ -70,6 +76,15 @@ sub file_exists {
 	return FALSE;
 }
 
+sub uri_exists {
+	my ( $self, $filename ) = @_;
+	return FALSE unless $filename;
+	$filename = $self->switch_home_in_file($filename);
+	my $new_uri = Gnome2::VFS::URI->new($filename);
+	return TRUE if $new_uri->exists;
+	return FALSE;
+}
+
 sub file_executable {
 	my ( $self, $filename ) = @_;
 	return FALSE unless $filename;
