@@ -39,7 +39,6 @@ use constant FALSE => 0;
 
 #--------------------------------------
 
-##################public subs##################
 sub new {
 	my $class = shift;
 
@@ -53,21 +52,62 @@ sub new {
 sub create_menu {
 	my $self = shift;
 
-	my $d           = $self->{_common}->get_gettext;
-	my $window      = $self->{_common}->get_mainwindow;
-	my $shutter_root = $self->{_common}->get_root;
+	my $d           	= $self->{_common}->get_gettext;
+	my $shutter_root 	= $self->{_common}->get_root;
 
 	my $accel_group = Gtk2::AccelGroup->new;
-	$window->add_accel_group($accel_group);
+	$self->{_common}->get_mainwindow->add_accel_group($accel_group);
+
+	#MenuBar
+	$self->{_menubar} = Gtk2::MenuBar->new();
+
+	#file
+	$self->{_menuitem_file} = Gtk2::MenuItem->new_with_mnemonic( $d->get('_File') );
+	$self->{_menuitem_file}->set_submenu( $self->fct_ret_file_menu( $accel_group, $d, $shutter_root ) );
+	$self->{_menubar}->append( $self->{_menuitem_file} );
+
+	#edit
+	$self->{_menuitem_edit} = Gtk2::MenuItem->new_with_mnemonic( $d->get('_Edit') );
+	$self->{_menuitem_edit}->set_submenu( $self->fct_ret_edit_menu( $accel_group, $d, $shutter_root ) );
+	$self->{_menubar}->append( $self->{_menuitem_edit} );
+
+	#view
+	$self->{_menuitem_view} = Gtk2::MenuItem->new_with_mnemonic( $d->get('_View') );
+	$self->{_menuitem_view}->set_submenu( $self->fct_ret_view_menu( $accel_group, $d, $shutter_root ) );
+	$self->{_menubar}->append( $self->{_menuitem_view} );
+	
+	#actions	
+	$self->{_menuitem_actions} = Gtk2::MenuItem->new_with_mnemonic( $d->get('_Screenshot') );
+	$self->{_menuitem_actions}->set_submenu( $self->fct_ret_actions_menu( $accel_group, $d, $shutter_root ) );
+	$self->{_menubar}->append( $self->{_menuitem_actions} );
+	
+	#go-to	
+	$self->{_menuitem_session} = Gtk2::MenuItem->new_with_mnemonic( $d->get('_Go') );
+	$self->{_menuitem_session}->set_submenu( $self->fct_ret_session_menu( $accel_group, $d, $shutter_root ) );
+	$self->{_menubar}->append( $self->{_menuitem_session} );
+	
+	#help
+	$self->{_menuitem_help} = Gtk2::MenuItem->new_with_mnemonic( $d->get('_Help') );
+	$self->{_menuitem_help}->set_submenu( $self->fct_ret_help_menu( $accel_group, $d, $shutter_root ) );
+	$self->{_menubar}->append( $self->{_menuitem_help} );
+
+	#we provide a larger (more actions) menuitem actions as well
+	#this will not be added to any menu entries
+	$self->fct_ret_actions_menu_large( $accel_group, $d, $shutter_root );
+
+	return $self->{_menubar};
+}
+
+sub fct_ret_file_menu {
+	my $self         = shift;
+	my $accel_group  = shift;
+	my $d            = shift;
+	my $shutter_root = shift;
 
 	#Icontheme
 	my $icontheme = $self->{_common}->get_theme;
 
-	$self->{_menubar} = Gtk2::MenuBar->new();
-
-	#file
 	$self->{_menu_file}     = Gtk2::Menu->new();
-	$self->{_menuitem_file} = Gtk2::MenuItem->new_with_mnemonic( $d->get('_File') );
 
 	$self->{_menuitem_new} = Gtk2::ImageMenuItem->new_from_stock('gtk-new');
 	$self->{_menuitem_new}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Control>N'), qw/visible/ );
@@ -76,7 +116,8 @@ sub create_menu {
 
 	$self->{_menu_file}->append( Gtk2::SeparatorMenuItem->new );
 
-	$self->{_menuitem_open} = Gtk2::ImageMenuItem->new_from_stock('gtk-open');
+	$self->{_menuitem_open} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Open...') );
+	$self->{_menuitem_open}->set_image( Gtk2::Image->new_from_stock( 'gtk-open', 'menu' ) );
 	$self->{_menuitem_open}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Control>O'), qw/visible/ );
 	$self->{_menu_file}->append( $self->{_menuitem_open} );
 
@@ -85,7 +126,8 @@ sub create_menu {
 
 	$self->{_menu_file}->append( Gtk2::SeparatorMenuItem->new );
 
-	$self->{_menuitem_save_as} = Gtk2::ImageMenuItem->new_from_stock('gtk-save-as');
+	$self->{_menuitem_save_as} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Save _As...') );
+	$self->{_menuitem_save_as}->set_image( Gtk2::Image->new_from_stock( 'gtk-save-as', 'menu' ) );
 	$self->{_menuitem_save_as}->set_sensitive(FALSE);
 	$self->{_menuitem_save_as}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Shift><Control>S'), qw/visible/ );
 	$self->{_menu_file}->append( $self->{_menuitem_save_as} );
@@ -99,14 +141,27 @@ sub create_menu {
 	$self->{_menuitem_pagesetup}->set_image(
 		Gtk2::Image->new_from_icon_name( 'document-page-setup', 'menu' )
 	);
+	$self->{_menuitem_pagesetup}->set_sensitive(FALSE);
 	$self->{_menu_file}->append( $self->{_menuitem_pagesetup} );
 
-	$self->{_menuitem_print} = Gtk2::ImageMenuItem->new_from_stock('gtk-print');
+	$self->{_menuitem_print} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Print...') );
+	$self->{_menuitem_print}->set_image( Gtk2::Image->new_from_stock( 'gtk-print', 'menu' ) );
 	$self->{_menuitem_print}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Control>P'), qw/visible/ );
+	$self->{_menuitem_print}->set_sensitive(FALSE);
 	$self->{_menu_file}->append( $self->{_menuitem_print} );
 
 	$self->{_menu_file}->append( Gtk2::SeparatorMenuItem->new );
 
+	$self->{_menuitem_email} = Gtk2::ImageMenuItem->new($d->get('Send by Email...'));
+	$self->{_menuitem_email}->set_image(
+		Gtk2::Image->new_from_icon_name( 'gnome-stock-mail-snd', 'menu' )
+	);
+	$self->{_menuitem_email}->set_sensitive(FALSE);
+	$self->{_menuitem_email}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Shift><Control>E'), qw/visible/ );
+	$self->{_menu_file}->append( $self->{_menuitem_email} );
+
+	$self->{_menu_file}->append( Gtk2::SeparatorMenuItem->new );
+
 	$self->{_menuitem_close} = Gtk2::ImageMenuItem->new_from_stock('gtk-close');
 	$self->{_menuitem_close}->set_sensitive(FALSE);
 	$self->{_menuitem_close}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Control>W'), qw/visible/ );
@@ -114,6 +169,7 @@ sub create_menu {
 
 	$self->{_menuitem_close_all} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('C_lose all') );
 	$self->{_menuitem_close_all}->set_image( Gtk2::Image->new_from_stock( 'gtk-close', 'menu' ) );
+	$self->{_menuitem_close_all}->set_sensitive(FALSE);
 	$self->{_menuitem_close_all}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Shift><Control>W'), qw/visible/ );
 	$self->{_menu_file}->append( $self->{_menuitem_close_all} );
 
@@ -122,15 +178,34 @@ sub create_menu {
 	$self->{_menuitem_quit} = Gtk2::ImageMenuItem->new_from_stock('gtk-quit');
 	$self->{_menuitem_quit}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Control>Q'), qw/visible/ );
 	$self->{_menu_file}->append( $self->{_menuitem_quit} );
+	
+	return $self->{_menu_file};
+}
+	
 
-	$self->{_menuitem_file}->set_submenu( $self->{_menu_file} );
-	$self->{_menubar}->append( $self->{_menuitem_file} );
+sub fct_ret_edit_menu {
+	my $self         = shift;
+	my $accel_group  = shift;
+	my $d            = shift;
+	my $shutter_root = shift;
 
-	#end file
+	#Icontheme
+	my $icontheme = $self->{_common}->get_theme;
 
-	#edit
 	$self->{_menu_edit} = Gtk2::Menu->new();
 
+	$self->{_menuitem_undo} = Gtk2::ImageMenuItem->new_from_stock('gtk-undo');
+	$self->{_menuitem_undo}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Control>Z'), qw/visible/ );
+	$self->{_menuitem_undo}->set_sensitive(FALSE);
+	$self->{_menu_edit}->append( $self->{_menuitem_undo} );
+
+	$self->{_menuitem_redo} = Gtk2::ImageMenuItem->new_from_stock('gtk-redo');
+	$self->{_menuitem_redo}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Control>Y'), qw/visible/ );
+	$self->{_menuitem_redo}->set_sensitive(FALSE);
+	$self->{_menu_edit}->append( $self->{_menuitem_redo} );
+
+	$self->{_menu_edit}->append( Gtk2::SeparatorMenuItem->new );
+
 	$self->{_menuitem_copy} = Gtk2::ImageMenuItem->new_from_stock('gtk-copy');
 	$self->{_menuitem_copy}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Control>C'), qw/visible/ );
 	$self->{_menuitem_copy}->set_sensitive(FALSE);
@@ -142,7 +217,7 @@ sub create_menu {
 	$self->{_menuitem_copy_filename}->set_sensitive(FALSE);
 	$self->{_menu_edit}->append( $self->{_menuitem_copy_filename} );
 
-	$self->{_menuitem_trash} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Move to Dele_ted Items folder') );
+	$self->{_menuitem_trash} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Move to _Trash') );
 	$self->{_menuitem_trash}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('Delete'), qw/visible/ );
 	$self->{_menuitem_trash}->set_image( Gtk2::Image->new_from_icon_name( 'gnome-stock-trash', 'menu' ) );
 	$self->{_menuitem_trash}->set_sensitive(FALSE);
@@ -165,13 +240,18 @@ sub create_menu {
 	$self->{_menuitem_settings}->add_accelerator( 'activate', $accel_group, $Gtk2::Gdk::Keysyms{P}, qw/mod1-mask/, qw/visible/ );
 	$self->{_menu_edit}->append( $self->{_menuitem_settings} );
 
-	$self->{_menuitem_edit} = Gtk2::MenuItem->new_with_mnemonic( $d->get('_Edit') );
-	$self->{_menuitem_edit}->set_submenu( $self->{_menu_edit} );
-	$self->{_menubar}->append( $self->{_menuitem_edit} );
+	return $self->{_menu_edit};
+}
 
-	#end edit
+sub fct_ret_view_menu {
+	my $self         = shift;
+	my $accel_group  = shift;
+	my $d            = shift;
+	my $shutter_root = shift;
+
+	#Icontheme
+	my $icontheme = $self->{_common}->get_theme;
 
-	#view
 	$self->{_menu_view} = Gtk2::Menu->new();
 
 	$self->{_menuitem_zoom_in} = Gtk2::ImageMenuItem->new_from_stock('gtk-zoom-in');
@@ -203,23 +283,19 @@ sub create_menu {
 	$self->{_menuitem_fullscreen} = Gtk2::CheckMenuItem->new_with_label($self->{_menuitem_fullscreen_image}->get_child->get_text);
 	$self->{_menuitem_fullscreen}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('F11'), qw/visible/ );
 	$self->{_menu_view}->append( $self->{_menuitem_fullscreen} );
+	
+	return $self->{_menu_view};
+}	
 
-	$self->{_menuitem_view} = Gtk2::MenuItem->new_with_mnemonic( $d->get('_View') );
-	$self->{_menuitem_view}->set_submenu( $self->{_menu_view} );
-	$self->{_menubar}->append( $self->{_menuitem_view} );
+sub fct_ret_session_menu {
+	my $self         = shift;
+	my $accel_group  = shift;
+	my $d            = shift;
+	my $shutter_root = shift;
 
-	#end view
-	
-	#actions
-	
-	$self->{_menuitem_actions} = Gtk2::MenuItem->new_with_mnemonic( $d->get('_Screenshot') );
-	$self->{_menuitem_actions}->set_submenu( $self->fct_ret_actions_menu( $accel_group, $d, $shutter_root ) );
-	$self->{_menubar}->append( $self->{_menuitem_actions} );
+	#Icontheme
+	my $icontheme = $self->{_common}->get_theme;
 
-	#end actions
-	
-	#session
-	
 	$self->{_menu_session} = Gtk2::Menu->new();
 
 	$self->{_menuitem_back} = Gtk2::ImageMenuItem->new_from_stock('gtk-go-back');
@@ -239,18 +315,22 @@ sub create_menu {
 	$self->{_menuitem_last} = Gtk2::ImageMenuItem->new_from_stock('gtk-goto-last');
 	$self->{_menuitem_last}->add_accelerator( 'activate', $accel_group, $Gtk2::Gdk::Keysyms{End}, qw/mod1-mask/, qw/visible/ );
 	$self->{_menu_session}->append( $self->{_menuitem_last} );
-
-	$self->{_menuitem_session} = Gtk2::MenuItem->new_with_mnemonic( $d->get('_Go') );
-	$self->{_menuitem_session}->set_submenu( $self->{_menu_session} );
-	$self->{_menubar}->append( $self->{_menuitem_session} );
-
-	#end session
-	
-	#help
 	
+	return $self->{_menu_session};
+}	
+
+sub fct_ret_help_menu {
+	my $self         = shift;
+	my $accel_group  = shift;
+	my $d            = shift;
+	my $shutter_root = shift;
+
+	#Icontheme
+	my $icontheme = $self->{_common}->get_theme;
+
 	$self->{_menu_help} = Gtk2::Menu->new();
 
-	$self->{_menuitem_question} = Gtk2::ImageMenuItem->new( $d->get('Get Help Online ...') );
+	$self->{_menuitem_question} = Gtk2::ImageMenuItem->new( $d->get('Get Help Online...') );
 	if($icontheme->has_icon('lpi-help')){
 		$self->{_menuitem_question}->set_image(
 			Gtk2::Image->new_from_icon_name( 'lpi-help', 'menu' )		
@@ -265,7 +345,7 @@ sub create_menu {
 
 	$self->{_menu_help}->append( $self->{_menuitem_question} );
 
-	$self->{_menuitem_translate} = Gtk2::ImageMenuItem->new( $d->get('Translate this Application ...') );
+	$self->{_menuitem_translate} = Gtk2::ImageMenuItem->new( $d->get('Translate this Application...') );
 	if($icontheme->has_icon('lpi-translate')){
 		$self->{_menuitem_translate}->set_image(
 			Gtk2::Image->new_from_icon_name( 'lpi-translate', 'menu' )		
@@ -301,24 +381,19 @@ sub create_menu {
 	$self->{_menuitem_about}->add_accelerator( 'activate', $accel_group, $Gtk2::Gdk::Keysyms{I}, qw/control-mask/, qw/visible/ );
 	$self->{_menu_help}->append( $self->{_menuitem_about} );
 
-	$self->{_menuitem_help} = Gtk2::MenuItem->new_with_mnemonic( $d->get('_Help') );
-	$self->{_menuitem_help}->set_submenu( $self->{_menu_help} );
-
-	$self->{_menubar}->append( $self->{_menuitem_help} );
-
-	return $self->{_menubar};
-}
+	return $self->{_menu_help};
+}	
 
 sub fct_ret_new_menu {
-	my $self        = shift;
-	my $accel_group = shift;
-	my $d           = shift;
+	my $self         = shift;
+	my $accel_group  = shift;
+	my $d            = shift;
 	my $shutter_root = shift;
 
 	#Icontheme
 	my $icontheme = $self->{_common}->get_theme;
 
-	$self->{_menu_new}           = Gtk2::Menu->new;
+	$self->{_menu_new} = Gtk2::Menu->new;
 	
 	#selection
 	$self->{_menuitem_selection} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Selection') );
@@ -372,6 +447,38 @@ sub fct_ret_new_menu {
 	}
 	$self->{_menu_new}->append( $self->{_menuitem_section} );
 
+	#menu
+	$self->{_menuitem_menu} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Menu') );
+	if($icontheme->has_icon('alacarte')){
+		$self->{_menuitem_menu}->set_image( Gtk2::Image->new_from_icon_name( 'alacarte', 'menu' ) );		
+	}else{
+		$self->{_menuitem_menu}->set_image(
+			Gtk2::Image->new_from_pixbuf(
+				Gtk2::Gdk::Pixbuf->new_from_file_at_size(
+					"$shutter_root/share/shutter/resources/icons/sel_window_menu.svg",
+					Gtk2::IconSize->lookup('menu')
+				)
+			)
+		);
+	}
+	$self->{_menu_new}->append( $self->{_menuitem_menu} );
+
+	#tooltip
+	$self->{_menuitem_tooltip} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Tooltip') );
+	#~ if($icontheme->has_icon('alacarte')){
+		#~ $self->{_menuitem_tooltip}->set_image( Gtk2::Image->new_from_icon_name( 'alacarte', 'menu' ) );		
+	#~ }else{
+		$self->{_menuitem_tooltip}->set_image(
+			Gtk2::Image->new_from_pixbuf(
+				Gtk2::Gdk::Pixbuf->new_from_file_at_size(
+					"$shutter_root/share/shutter/resources/icons/sel_window_tooltip.svg",
+					Gtk2::IconSize->lookup('menu')
+				)
+			)
+		);
+	#~ }
+	$self->{_menu_new}->append( $self->{_menuitem_tooltip} );
+
 	$self->{_menu_new}->append( Gtk2::SeparatorMenuItem->new );
 
 	#web
@@ -387,6 +494,14 @@ sub fct_ret_new_menu {
 	}
 	$self->{_menu_new}->append( $self->{_menuitem_web} );
 
+	$self->{_menu_new}->append( Gtk2::SeparatorMenuItem->new );
+
+	#import from clipboard
+	$self->{_menuitem_iclipboard} = Gtk2::ImageMenuItem->new_from_stock('gtk-paste');
+	$self->{_menuitem_iclipboard}->get_child->set_text_with_mnemonic( $d->get('Import from clip_board') );
+	$self->{_menuitem_iclipboard}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Control><Shift>V'), qw/visible/ );
+	$self->{_menu_new}->append( $self->{_menuitem_iclipboard} );
+
 	$self->{_menu_new}->show_all;
 
 	return $self->{_menu_new};
@@ -417,7 +532,7 @@ sub fct_ret_actions_menu{
 	$self->{_menuitem_reopen}->set_name('item-reopen-list');
 	$self->{_menu_actions}->append( $self->{_menuitem_reopen} );
 
-	$self->{_menuitem_rename} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Rename') );
+	$self->{_menuitem_rename} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Rename...') );
 	$self->{_menuitem_rename}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('F2'), qw/visible/ ) if $accel_group;
 	$self->{_menuitem_rename}->set_image( Gtk2::Image->new_from_stock( 'gtk-edit', 'menu' ) );
 	$self->{_menuitem_rename}->set_sensitive(FALSE);
@@ -426,7 +541,16 @@ sub fct_ret_actions_menu{
 
 	$self->{_menu_actions}->append( Gtk2::SeparatorMenuItem->new );
 
-	$self->{_menuitem_upload} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Upload / Export') );
+	$self->{_menuitem_send} = Gtk2::ImageMenuItem->new($d->get('Send To...'));
+	$self->{_menuitem_send}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Control>S'), qw/visible/ );
+	$self->{_menuitem_send}->set_image(
+		Gtk2::Image->new_from_icon_name( 'document-send', 'menu' )
+	);
+	$self->{_menuitem_send}->set_sensitive(FALSE);
+	$self->{_menuitem_send}->set_name('item-send');
+	$self->{_menu_actions}->append( $self->{_menuitem_send} );
+
+	$self->{_menuitem_upload} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('E_xport...') );
 	$self->{_menuitem_upload}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Control>U'), qw/visible/ ) if $accel_group;
 	$self->{_menuitem_upload}->set_image( Gtk2::Image->new_from_stock( 'gtk-network', 'menu' ) );
 	$self->{_menuitem_upload}->set_sensitive(FALSE);
@@ -435,7 +559,8 @@ sub fct_ret_actions_menu{
 
 	$self->{_menu_actions}->append( Gtk2::SeparatorMenuItem->new );
 
-	$self->{_menuitem_draw} = Gtk2::ImageMenuItem->new_from_stock( 'gtk-edit' );
+	$self->{_menuitem_draw} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Edit...') );
+	$self->{_menuitem_draw}->set_image( Gtk2::Image->new_from_stock( 'gtk-edit', 'menu' ) );
 	$self->{_menuitem_draw}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Control>E'), qw/visible/ ) if $accel_group;
 	if($icontheme->has_icon('applications-graphics')){
 		$self->{_menuitem_draw}->set_image( Gtk2::Image->new_from_icon_name( 'applications-graphics', 'menu' ) );		
@@ -451,7 +576,7 @@ sub fct_ret_actions_menu{
 	$self->{_menuitem_draw}->set_name('item-draw');
 	$self->{_menu_actions}->append( $self->{_menuitem_draw} );
 
-	$self->{_menuitem_plugin} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Execute a _plugin') );
+	$self->{_menuitem_plugin} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Run a _plugin...') );
 	$self->{_menuitem_plugin}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Control><Shift>P'), qw/visible/ ) if $accel_group;
 	$self->{_menuitem_plugin}->set_image( Gtk2::Image->new_from_stock( 'gtk-execute', 'menu' ) );
 	$self->{_menuitem_plugin}->set_sensitive(FALSE);
@@ -464,4 +589,100 @@ sub fct_ret_actions_menu{
 	
 }
 
+sub fct_ret_actions_menu_large{
+	my $self        = shift;
+	my $accel_group = shift;
+	my $d           = shift;
+	my $shutter_root = shift;
+	
+	#Icontheme
+	my $icontheme = $self->{_common}->get_theme;
+	
+	$self->{_menu_large_actions} = Gtk2::Menu->new();
+
+	$self->{_menuitem_large_reopen_default} = Gtk2::ImageMenuItem->new_with_mnemonic( 
+			sprintf( $d->get('_Open with %s'), ''),
+ 		);
+	$self->{_menuitem_large_reopen_default}->set_image( Gtk2::Image->new_from_stock( 'gtk-open', 'menu' ) );
+	$self->{_menuitem_large_reopen_default}->set_sensitive(FALSE);
+	$self->{_menuitem_large_reopen_default}->set_name('item-large-reopen-default');
+	$self->{_menu_large_actions}->append( $self->{_menuitem_large_reopen_default} );
+
+	$self->{_menuitem_large_reopen} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Open wit_h') );
+	$self->{_menuitem_large_reopen}->set_image( Gtk2::Image->new_from_stock( 'gtk-open', 'menu' ) );
+	$self->{_menuitem_large_reopen}->set_sensitive(FALSE);
+	$self->{_menuitem_large_reopen}->set_name('item-large-reopen-list');
+	$self->{_menu_large_actions}->append( $self->{_menuitem_large_reopen} );
+
+	$self->{_menuitem_large_rename} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Rename...') );
+	$self->{_menuitem_large_rename}->set_image( Gtk2::Image->new_from_stock( 'gtk-edit', 'menu' ) );
+	$self->{_menuitem_large_rename}->set_sensitive(FALSE);
+	$self->{_menuitem_large_rename}->set_name('item-large-rename');
+	$self->{_menu_large_actions}->append( $self->{_menuitem_large_rename} );
+
+	$self->{_menu_large_actions}->append( Gtk2::SeparatorMenuItem->new );
+
+	$self->{_menuitem_large_send} = Gtk2::ImageMenuItem->new($d->get('Send To...'));
+	$self->{_menuitem_large_send}->set_image(
+		Gtk2::Image->new_from_icon_name( 'document-send', 'menu' )
+	);
+	$self->{_menuitem_send}->set_sensitive(FALSE);
+	$self->{_menuitem_send}->set_name('item-large-send');
+	$self->{_menu_large_actions}->append( $self->{_menuitem_large_send} );
+
+	$self->{_menuitem_large_upload} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('E_xport...') );
+	$self->{_menuitem_large_upload}->set_image( Gtk2::Image->new_from_stock( 'gtk-network', 'menu' ) );
+	$self->{_menuitem_large_upload}->set_sensitive(FALSE);
+	$self->{_menuitem_large_upload}->set_name('item-large-upload');
+	$self->{_menu_large_actions}->append( $self->{_menuitem_large_upload} );
+
+	$self->{_menu_large_actions}->append( Gtk2::SeparatorMenuItem->new );
+
+	$self->{_menuitem_large_copy} = Gtk2::ImageMenuItem->new_from_stock('gtk-copy');
+	$self->{_menuitem_large_copy}->set_sensitive(FALSE);
+	$self->{_menuitem_large_copy}->set_name('item-large-copy');
+	$self->{_menu_large_actions}->append( $self->{_menuitem_large_copy} );
+
+	$self->{_menuitem_large_copy_filename} = Gtk2::ImageMenuItem->new_from_stock('gtk-copy');
+	$self->{_menuitem_large_copy_filename}->get_child->set_text_with_mnemonic( $d->get('Copy _filename') );	
+	$self->{_menuitem_large_copy_filename}->set_sensitive(FALSE);
+	$self->{_menuitem_large_copy_filename}->set_name('item-large-copy-filename');
+	$self->{_menu_large_actions}->append( $self->{_menuitem_large_copy_filename} );
+
+	$self->{_menuitem_large_trash} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Move to _Trash') );
+	$self->{_menuitem_large_trash}->set_image( Gtk2::Image->new_from_icon_name( 'gnome-stock-trash', 'menu' ) );
+	$self->{_menuitem_large_trash}->set_sensitive(FALSE);
+	$self->{_menuitem_large_trash}->set_name('item-large-trash');
+	$self->{_menu_large_actions}->append( $self->{_menuitem_large_trash} );
+
+	$self->{_menu_large_actions}->append( Gtk2::SeparatorMenuItem->new );
+
+	$self->{_menuitem_large_draw} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Edit...') );
+	$self->{_menuitem_large_draw}->set_image( Gtk2::Image->new_from_stock( 'gtk-edit', 'menu' ) );
+	if($icontheme->has_icon('applications-graphics')){
+		$self->{_menuitem_large_draw}->set_image( Gtk2::Image->new_from_icon_name( 'applications-graphics', 'menu' ) );		
+	}else{
+		$self->{_menuitem_large_draw}->set_image(
+			Gtk2::Image->new_from_pixbuf(
+				Gtk2::Gdk::Pixbuf->new_from_file_at_size( "$shutter_root/share/shutter/resources/icons/draw.svg", Gtk2::IconSize->lookup('menu') )
+			)
+		);
+	}
+	
+	$self->{_menuitem_large_draw}->set_sensitive(FALSE);
+	$self->{_menuitem_large_draw}->set_name('item-large-draw');
+	$self->{_menu_large_actions}->append( $self->{_menuitem_large_draw} );
+
+	$self->{_menuitem_large_plugin} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Run a _plugin...') );
+	$self->{_menuitem_large_plugin}->set_image( Gtk2::Image->new_from_stock( 'gtk-execute', 'menu' ) );
+	$self->{_menuitem_large_plugin}->set_sensitive(FALSE);
+	$self->{_menuitem_large_plugin}->set_name('item-large-plugin');
+	$self->{_menu_large_actions}->append( $self->{_menuitem_large_plugin} );
+	
+	$self->{_menu_large_actions}->show_all;
+	
+	return $self->{_menu_large_actions};
+	
+}
+
 1;
