@@ -44,18 +44,20 @@ sub new {
 				 _sc  => shift,
 				 _include_cursor => shift,
 				 _delay          => shift,
+				 _notify_timeout => shift,
 			   };
 			
 	#root window
 	$self->{ _root } = Gtk2::Gdk->get_default_root_window;
-	(
-	   $self->{ _root }->{ x },
-	   $self->{ _root }->{ y },
-	   $self->{ _root }->{ w },
-	   $self->{ _root }->{ h }
-	) = $self->{ _root }->get_geometry;
-	( $self->{ _root }->{ x }, $self->{ _root }->{ y } ) =
-		$self->{ _root }->get_origin;
+	( $self->{ _root }->{ x }, $self->{ _root }->{ y }, $self->{ _root }->{ w }, $self->{ _root }->{ h } ) = $self->{ _root }->get_geometry;
+	( $self->{ _root }->{ x }, $self->{ _root }->{ y } ) = $self->{ _root }->get_origin;
+	
+	#import modules
+	require lib;
+	import lib $self->{_sc}->get_root."/share/shutter/resources/modules";
+
+	#shutter region module
+	require Shutter::Geometry::Region;
 
 	#wnck screen
 	$self->{_wnck_screen} = Gnome2::Wnck::Screen->get_default;
@@ -87,6 +89,16 @@ sub new {
 	return $self;
 }
 
+sub get_clipbox {
+	my $self 	= shift;
+	my $region 	= shift;
+
+	#create shutter region object
+	my $sr = Shutter::Geometry::Region->new();
+	
+	return $sr->get_clipbox($region);
+}	
+
 sub update_workspaces {
 	my $self = shift;
 	for ( my $wcount = 0 ; $wcount < $self->{_wnck_screen}->get_workspace_count ; $wcount++ )
@@ -153,7 +165,7 @@ sub ungrab_pointer_and_keyboard {
 		#~ my ( $tmpfh, $tmpfilename ) = tempfile(UNLINK => 1);
 		#~ 
 		#~ my ($pixbuf, $l_cropped, $r_cropped, $t_cropped, $b_cropped) = $self->get_pixbuf_from_drawable($drawable, $x, $y, $width, $height, FALSE, 1);
-		#~ $pixbuf_save->save_pixbuf_to_file($pixbuf, $tmpfilename, $tmpfilename, 'miff');
+		#~ $pixbuf_save->save_pixbuf_to_file($pixbuf, $tmpfilename, 'miff');
 	#~ 
 		#~ push @steps, $tmpfilename;		
 		#~ 
@@ -199,10 +211,55 @@ sub ungrab_pointer_and_keyboard {
 #~ }	
 
 sub get_pixbuf_from_drawable {
-	my ( $self, $drawable, $x, $y, $width, $height, $multi_monitor ) = @_;
+	my ( $self, $drawable, $x, $y, $width, $height, $region ) = @_;
 
 	my ($pixbuf, $l_cropped, $r_cropped, $t_cropped, $b_cropped) = (0, 0, 0, 0, 0);
 
+	#show notification messages displaying the countdown
+	if($self->{_delay} && $self->{_notify_timeout}){
+		my $notify 	= $self->{_sc}->get_notification_object;
+		my $ttw 	= $self->{_delay};
+
+		#gettext
+		my $d = $self->{_sc}->get_gettext;
+
+		#first notification immediately
+		$notify->show( sprintf($d->nget("Screenshot will be taken in %s second", "Screenshot will be taken in %s seconds", $ttw) , $ttw), "" );
+		$ttw--;
+		
+		#delay is only 1 second
+		#do not show any further messages
+		if($ttw >= 1){
+			#then controlled via timeout
+			Glib::Timeout->add (1000, sub{
+				$notify->show( sprintf($d->nget("Screenshot will be taken in %s second", "Screenshot will be taken in %s seconds", $ttw) , $ttw), "" );
+				$ttw--;
+				if($ttw == 0){			
+					
+					#close last message with a short delay (less than a second)
+					Glib::Timeout->add (500, sub{
+						$notify->close;
+						return FALSE;	
+					});	
+					
+					return FALSE;
+					
+				}else{
+					
+					return TRUE;	
+				
+				}	
+			});
+		}else{
+			#close last message with a short delay (less than a second)
+			Glib::Timeout->add (500, sub{
+				$notify->close;
+				return FALSE;	
+			});				
+		}	
+	
+	}		
+
 	#Add a timeout if there is any delay
 	Glib::Timeout->add ($self->{_delay}*1000, sub{	
 
@@ -247,25 +304,34 @@ sub get_pixbuf_from_drawable {
 			$pixbuf = $self->include_cursor( $x, $y, $width, $height, $drawable, $pixbuf );
 		}
 
-		#When there are multiple monitors with different resolutions, the visible area
-		#within the root window may not be rectangular (it may have an L-shape, for
-		#example). In that case, mask out the areas of the root window which would
-		#not be visible in the monitors, so that screenshot do not end up with content
-		#that the user won't ever see.
- 		#
-		#comment copied from gnome-screenshot
-		#http://svn.gnome.org/viewvc/gnome-utils/trunk/gnome-screenshot/screenshot-utils.c?view=markup
-		if($multi_monitor){
-			#create target pixbuf with dimension of monitor layout
-			my $m_rect = $self->get_monitor_region->get_clipbox;
-			my $target = Gtk2::Gdk::Pixbuf->new ($pixbuf->get_colorspace, TRUE, 8, $m_rect->width, $m_rect->height);
+		#region is optional
+		#it is used to handle multiple monitors (root window may not be rectangular)
+		#or to cut out the screen contents when capturing menus
+		if($region){
+			#get clipbox
+			#~ my $clipbox = $region->get_clipbox;
+			my $clipbox = $self->get_clipbox($region);
+			
+			#~ print "Clipbox: ", $clipbox->width, " - ", $clipbox->height, "\n";
+			
+			#create target pixbuf with dimension of clipbox
+			my $target = Gtk2::Gdk::Pixbuf->new ($pixbuf->get_colorspace, TRUE, 8, $clipbox->width, $clipbox->height);
 			
 			#whole pixbuf is transparent
 			$target->fill(0x00000000);
+
+			#determine low x and y
+			my $small_x = $self->{ _root }->{ w };
+			my $small_y = $self->{ _root }->{ h };
+			foreach my $r ($region->get_rectangles){
+				$small_x = $r->x if $r->x < $small_x; 
+				$small_y = $r->y if $r->y < $small_y; 
+			}
 			
 			#copy each rectangle
-			foreach my $r ($self->get_monitor_region->get_rectangles){
-				$pixbuf->copy_area ($r->x, $r->y, $r->width, $r->height, $target, $r->x, $r->y);
+			foreach my $r ($region->get_rectangles){
+				#~ print $r->x, " - ", $r->y, " - ", $r->width, " - ", $r->height, "\n";
+				$pixbuf->copy_area ($r->x - $small_x, $r->y - $small_y, $r->width, $r->height, $target, $r->x - $small_x, $r->y - $small_y);
 			}
 			$pixbuf = $target->copy;			
 		}
